==> zio-aws-securityhub_2.13-5.17.128.1-sources.jar: zio/aws/securityhub/model/AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.Integer
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails(
    capabilities: Option[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails
    ] = None,
    devices: Option[Iterable[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails
    ]] = None,
    initProcessEnabled: Option[Boolean] = None,
    maxSwap: Option[Integer] = None,
    sharedMemorySize: Option[Integer] = None,
    swappiness: Option[Integer] = None,
    tmpfs: Option[Iterable[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails
    ]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails = {
    import AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails
      .builder()
      .optionallyWith(capabilities.map(value => value.buildAwsValue()))(
        _.capabilities
      )
      .optionallyWith(
        devices.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.devices)
      .optionallyWith(
        initProcessEnabled.map(value => value: java.lang.Boolean)
      )(_.initProcessEnabled)
      .optionallyWith(
        maxSwap.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.maxSwap)
      .optionallyWith(
        sharedMemorySize.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.sharedMemorySize)
      .optionallyWith(
        swappiness.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.swappiness)
      .optionallyWith(
        tmpfs.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tmpfs)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails.ReadOnly =
    zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails
      .wrap(buildAwsValue())
}
object AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails =
      zio.aws.securityhub.model
        .AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails(
          capabilities.map(value => value.asEditable),
          devices.map(value =>
            value.map { item =>
              item.asEditable
            }
          ),
          initProcessEnabled.map(value => value),
          maxSwap.map(value => value),
          sharedMemorySize.map(value => value),
          swappiness.map(value => value),
          tmpfs.map(value =>
            value.map { item =>
              item.asEditable
            }
          )
        )
    def capabilities: Option[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails.ReadOnly
    ]
    def devices: Option[List[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails.ReadOnly
    ]]
    def initProcessEnabled: Option[Boolean]
    def maxSwap: Option[Integer]
    def sharedMemorySize: Option[Integer]
    def swappiness: Option[Integer]
    def tmpfs: Option[List[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails.ReadOnly
    ]]
    def getCapabilities: ZIO[
      Any,
      AwsError,
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails.ReadOnly
    ] = AwsError.unwrapOptionField("capabilities", capabilities)
    def getDevices: ZIO[Any, AwsError, List[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails.ReadOnly
    ]] = AwsError.unwrapOptionField("devices", devices)
    def getInitProcessEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("initProcessEnabled", initProcessEnabled)
    def getMaxSwap: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("maxSwap", maxSwap)
    def getSharedMemorySize: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("sharedMemorySize", sharedMemorySize)
    def getSwappiness: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("swappiness", swappiness)
    def getTmpfs: ZIO[Any, AwsError, List[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails.ReadOnly
    ]] = AwsError.unwrapOptionField("tmpfs", tmpfs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails
  ) extends zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails.ReadOnly {
    override val capabilities: Option[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails.ReadOnly
    ] = scala
      .Option(impl.capabilities())
      .map(value =>
        zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails
          .wrap(value)
      )
    override val devices: Option[List[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails.ReadOnly
    ]] = scala
      .Option(impl.devices())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails
            .wrap(item)
        }.toList
      )
    override val initProcessEnabled: Option[Boolean] =
      scala.Option(impl.initProcessEnabled()).map(value => value: Boolean)
    override val maxSwap: Option[Integer] = scala
      .Option(impl.maxSwap())
      .map(value => zio.aws.securityhub.model.primitives.Integer(value))
    override val sharedMemorySize: Option[Integer] = scala
      .Option(impl.sharedMemorySize())
      .map(value => zio.aws.securityhub.model.primitives.Integer(value))
    override val swappiness: Option[Integer] = scala
      .Option(impl.swappiness())
      .map(value => zio.aws.securityhub.model.primitives.Integer(value))
    override val tmpfs: Option[List[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails.ReadOnly
    ]] = scala
      .Option(impl.tmpfs())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails
            .wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails
  ): zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-5.17.157.2-sources.jar: zio/aws/securityhub/model/AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.Integer
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails(
    capabilities: Option[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails
    ] = None,
    devices: Option[Iterable[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails
    ]] = None,
    initProcessEnabled: Option[Boolean] = None,
    maxSwap: Option[Integer] = None,
    sharedMemorySize: Option[Integer] = None,
    swappiness: Option[Integer] = None,
    tmpfs: Option[Iterable[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails
    ]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails = {
    import AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails
      .builder()
      .optionallyWith(capabilities.map(value => value.buildAwsValue()))(
        _.capabilities
      )
      .optionallyWith(
        devices.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.devices)
      .optionallyWith(
        initProcessEnabled.map(value => value: java.lang.Boolean)
      )(_.initProcessEnabled)
      .optionallyWith(maxSwap.map(value => value: java.lang.Integer))(_.maxSwap)
      .optionallyWith(sharedMemorySize.map(value => value: java.lang.Integer))(
        _.sharedMemorySize
      )
      .optionallyWith(swappiness.map(value => value: java.lang.Integer))(
        _.swappiness
      )
      .optionallyWith(
        tmpfs.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tmpfs)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails.ReadOnly =
    zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails
      .wrap(buildAwsValue())
}
object AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails =
      zio.aws.securityhub.model
        .AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails(
          capabilities.map(value => value.asEditable),
          devices.map(value =>
            value.map { item =>
              item.asEditable
            }
          ),
          initProcessEnabled.map(value => value),
          maxSwap.map(value => value),
          sharedMemorySize.map(value => value),
          swappiness.map(value => value),
          tmpfs.map(value =>
            value.map { item =>
              item.asEditable
            }
          )
        )
    def capabilities: Option[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails.ReadOnly
    ]
    def devices: Option[List[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails.ReadOnly
    ]]
    def initProcessEnabled: Option[Boolean]
    def maxSwap: Option[Integer]
    def sharedMemorySize: Option[Integer]
    def swappiness: Option[Integer]
    def tmpfs: Option[List[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails.ReadOnly
    ]]
    def getCapabilities: ZIO[
      Any,
      AwsError,
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails.ReadOnly
    ] = AwsError.unwrapOptionField("capabilities", capabilities)
    def getDevices: ZIO[Any, AwsError, List[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails.ReadOnly
    ]] = AwsError.unwrapOptionField("devices", devices)
    def getInitProcessEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("initProcessEnabled", initProcessEnabled)
    def getMaxSwap: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("maxSwap", maxSwap)
    def getSharedMemorySize: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("sharedMemorySize", sharedMemorySize)
    def getSwappiness: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("swappiness", swappiness)
    def getTmpfs: ZIO[Any, AwsError, List[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails.ReadOnly
    ]] = AwsError.unwrapOptionField("tmpfs", tmpfs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails
  ) extends zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails.ReadOnly {
    override val capabilities: Option[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails.ReadOnly
    ] = scala
      .Option(impl.capabilities())
      .map(value =>
        zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails
          .wrap(value)
      )
    override val devices: Option[List[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails.ReadOnly
    ]] = scala
      .Option(impl.devices())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails
            .wrap(item)
        }.toList
      )
    override val initProcessEnabled: Option[Boolean] =
      scala.Option(impl.initProcessEnabled()).map(value => value: Boolean)
    override val maxSwap: Option[Integer] =
      scala.Option(impl.maxSwap()).map(value => value: Integer)
    override val sharedMemorySize: Option[Integer] =
      scala.Option(impl.sharedMemorySize()).map(value => value: Integer)
    override val swappiness: Option[Integer] =
      scala.Option(impl.swappiness()).map(value => value: Integer)
    override val tmpfs: Option[List[
      zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails.ReadOnly
    ]] = scala
      .Option(impl.tmpfs())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails
            .wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails
  ): zio.aws.securityhub.model.AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails.ReadOnly =
    new Wrapper(impl)
}
